@@ -22,6 +22,9 @@ from .strategies import (
     GLD,
     SimAnneal,
 )
+from .utils import FitnessShaper, ParameterReshaper, ESLog
+from .networks import NetworkMapper
+from .problems import ProblemMapper
 
 
 Strategies = {
@@ -48,11 +51,6 @@ Strategies = {
     "SimAnneal": SimAnneal,
 }
 
-from .utils import FitnessShaper, ParameterReshaper, ESLog
-from .networks import NetworkMapper
-from .problems import ProblemMapper
-from .subpops import BatchStrategy, Protocol, MetaStrategy
-
 __all__ = [
     "Strategy",
     "SimpleGA",
@@ -82,7 +80,4 @@ __all__ = [
     "ESLog",
     "NetworkMapper",
     "ProblemMapper",
-    "BatchStrategy",
-    "Protocol",
-    "MetaStrategy",
 ]
