@@ -12,13 +12,16 @@ class ParameterReshaper(object):
         placeholder_params: Union[chex.ArrayTree, chex.Array],
         identity: bool = False,
         n_devices: Optional[int] = None,
+        separator: str = '$',
+        verbose: bool = True,
     ):
         """Reshape flat parameters vectors into generation eval shape."""
+        self._separator = separator
         # Get network shape to reshape
         self.placeholder_params = placeholder_params
         if type(placeholder_params) == dict:
             flat_params = {
-                "/".join(k): v
+                self._separator.join(k): v
                 for k, v in flatten_dict(self.placeholder_params).items()
             }
             self.unflat_shape = jax.tree_map(jnp.shape, self.placeholder_params)
@@ -28,7 +31,7 @@ class ParameterReshaper(object):
         elif type(placeholder_params) == FrozenDict:
             self.placeholder_params = unfreeze(self.placeholder_params)
             flat_params = {
-                "/".join(k): v
+                self._separator.join(k): v
                 for k, v in flatten_dict(self.placeholder_params).items()
             }
             self.unflat_shape = jax.tree_map(jnp.shape, self.placeholder_params)
@@ -51,13 +54,19 @@ class ParameterReshaper(object):
             self.n_devices = jax.local_device_count()
         else:
             self.n_devices = n_devices
-        if self.n_devices > 1:
+        if self.n_devices > 1 and verbose:
             print(
                 f"ParameterReshaper: {self.n_devices} devices detected. Please"
                 " make sure that the ES population size divides evenly across"
                 " the number of devices to pmap/parallelize over."
             )
 
+        if verbose:
+            print(
+                f"ParameterReshaper: {self.total_params} parameters detected"
+                " for optimization."
+            )
+
     def reshape_identity(self, x: chex.Array) -> chex.Array:
         """Return parameters w/o reshaping for evaluation."""
         return x
@@ -103,7 +112,7 @@ class ParameterReshaper(object):
             # Place reshaped params into dict and increase counter
             new_nn[p_k] = p_reshaped
         return unflatten_dict(
-            {tuple(k.split("/")): v for k, v in new_nn.items()}
+            {tuple(k.split(self._separator)): v for k, v in new_nn.items()}
         )
 
     def split_params_for_pmap(self, param: chex.Array) -> chex.Array:
